# nutrition-pad
Nutrition display fo local network.

If you work from home. It may make sense to have dedicated tablets (which can be cheaply obtained - nexus 10 tablets are very cheap) for food entry with a limited number of items. In my experience tools like myfitnesspal become *very* annoying to us over time.

The other motivation is to separate recording from calorie display.
